import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  scaleSequential,
  schemeYlOrRd,
  interpolateYlOrRd,
  max,
  extent,
} from 'd3';
import { useWorldAtlas } from './useWorldAtlas';
import { useCases } from './useCases';
import { useCountryCodes } from './useCountryCodes';
import { Marks } from './Marks';

const height = 500;
const width = 960;
const padding = 20;
const centerX = width / 2;
const centerY = height / 2;
const selectedYear = '2017';

const App = () => {
  const worldAtlas = useWorldAtlas();
  const cases = useCases();
  const codes = useCountryCodes();

  if (!worldAtlas || !cases || !codes) {
    return <pre>Loading...</pre>;
  }

  const filteredCases = cases.filter((d) =>
    d.year == selectedYear ? true : false
  );

  const numericCodeByAlphaCode = new Map();
  codes.forEach((code) => {
    const alpha3Code = code['alpha-3'];
    const numericCode = code['country-code'];
		 numericCodeByAlphaCode.set(alpha3Code, numericCode);
  });
  console.log(codes);
  
  const rowByCode = new Map();
  filteredCases.forEach((d) => {
    const alpha3Code = d.Code;
    const numericCode = numericCodeByAlphaCode.get(alpha3Code);
    rowByCode.set(numericCode, d);
  });

  console.log(rowByCode);

  const colorValue = (d) => d.aids;
  const colorScale = scaleSequential(
    interpolateYlOrRd
  ).domain([0, max(cases, colorValue)]);

  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        cases={cases}
        colorScale={colorScale}
        colorValue={colorValue}
        rowByCode={rowByCode}
      />
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
